<!--
This file is part of AsicVerifier and is released under
the AGPL-3.0-only License: https://opensource.org/license/agpl-v3/
-->

# AsicVerifier

[![License](https://img.shields.io/github/license/pipinfitriadi/asicverifier?logoColor=black&label=License&labelColor=black&color=brightgreen)](https://github.com/pipinfitriadi/asicverifier/blob/main/LICENSE)
[![Java - Version](https://img.shields.io/badge/8-ED8B00?logo=openjdk&logoColor=ED8B00&label=Java&labelColor=black)](https://openjdk.org/projects/jdk8/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/asicverifier?logo=python&label=Python&labelColor=black)](https://pypi.org/project/asicverifier/)
[![PyPI - Version](https://img.shields.io/pypi/v/asicverifier?logo=pypi&label=PyPI&labelColor=black)](https://pypi.org/project/asicverifier/)
[![Docker Image Size (tag)](https://img.shields.io/docker/image-size/pipinfitriadi/asicverifier/latest?logo=Docker&label=latest&labelColor=black)](https://hub.docker.com/r/pipinfitriadi/asicverifier)
[![GitHub Action](https://img.shields.io/github/actions/workflow/status/pipinfitriadi/asicverifier/ci-cd.yml?logo=GitHub&label=CI%2FCD&labelColor=black)](https://github.com/pipinfitriadi/asicverifier/actions/workflows/ci-cd.yml)
[![Codecov](https://img.shields.io/codecov/c/github/pipinfitriadi/asicverifier?logo=codecov&label=Coverage&labelColor=black)](https://app.codecov.io/github/pipinfitriadi/asicverifier)

Asic Verifier for X-Road
